******** Beginning of example5.do **********************************************
/*
  Demonstrate the use of -descsave-, -xcontract-, -factext-, -factmerg- and -ingap-
  to create plots and tables from a -parmby- resultsset with the -label- option.
  Unofficial Stata packages required:
  -descsave-, -parmest-, -factext-, -factmerg-, -sencode-, -sdecode-, -ingap-,
  -eclplot-, -listtex-.
*/

version 8.0

set scheme s1mono

sysuse auto, clear

/*
  Define baseline reference categories for -foreign- and -rep78-
*/

char foreign[omit] 0
char rep78[omit] 3
describe
char list
more

/*
  Create a do-file to reconstruct -foreign- and -rep78-
*/

tempfile tf0
descsave foreign rep78, dofile(`tf0', replace) char(omit)
more

/*
  Create -xcontract- resultssets for -foreign- and -rep78-
*/

tempfile tf1 tf2
xcontract foreign if !missing(rep78), list(,) saving(`tf1', replace)
more
xcontract rep78 if !missing(rep78), list(,) saving(`tf2', replace)
more

/*
  Create a -parmby- resultsset of regression parameters
*/

parmby  "xi: regress mpg i.foreign i.rep78, robust", ///
  label norestore format(estimate min95 max95 %8.2f p %-8.2g)
more
describe
more
list parm label estimate min95 max95, noobs clean
more

/*
  Extract factors from string variable -label-
*/

factext, dofile(`tf0')
describe
more
list parm label foreign rep78 estimate min95 max95, noobs clean
more

/*
  Merge in -xcontract- resultssets
*/

sort foreign
merge foreign using `tf1', update
drop _merge
sort rep78
merge rep78 using `tf2', update
drop _merge
sort foreign rep78
describe
more
list parm label foreign rep78 _freq estimate min95 max95, noobs clean
more

/*
  Fill in zero confidence intervals for reference factor values
*/

foreach X of var foreign rep78 {
  foreach Y of var estimate min95 max95 {
    replace `Y'=0 if `X'==``X'[omit]'
  }
}
list parm label foreign rep78 _freq estimate min95 max95, noobs clean
more

/*
  Generate factor label and value variables
*/

factmerg foreign rep78, flabel(faclab) fvalue(facval)
describe
more
list parm label faclab facval estimate min95 max95, noobs clean compress
more

/*
  Generate row label variable -cargp- and add gap observations
*/

generate cargp=facval+" (n="+string(_freq)+")" if !missing(facval)
sencode faclab, generate(factor)
bysort factor faclab (foreign rep78): ingap 1 if !missing(factor), ///
  rowlabel(cargp) grexpression(faclab+":")
sencode cargp, manyto1 replace
lab var cargp "Car group"
sort cargp
describe
more
list parm label cargp estimate min95 max95, noobs clean
more

/*
  Plot confidence intervals against -cargp-
*/

eclplot estimate min* max* cargp, horizontal ///
  yscale(range(0 10)) ylab(1(1)9, notick) ///
  xline(0, lpattern(shortdash)) ///
  xtitle("Difference in mileage (mpg)") ///
  estopts(mcolor(black) msize(large)) ///
  ciopts(msize(huge) blcolor(black))
* To save Figure 1 to disk, insert the line:
* graph save figure1, replace
more

/*
  Create LaTeX -tabular- environment for table
*/

sdecode estimate, replace
sdecode min95, replace
sdecode max95, replace
foreach X of var estimate min* max* {
  replace `X'=subinstr(`X',"-","$-$",1)
}
replace min95="("+min95+"," if !missing(min95)
replace max95=max95+")" if !missing(max95)
foreach X of var foreign rep78 {
  replace min95="(ref.)" if `X'==``X'[omit]'
  replace max95="" if `X'==``X'[omit]'
}
list parm cargp estimate min95 max95 p, noobs clean
more
listtex cargp estimate min95 max95 p if !missing(factor), rstyle(tabular) type ///
  headline("\begin{tabular}{rrrrl}" "\hline" ///
    "\textit{Car group}&\textit{Difference (mpg)}&\textit{(95\%}&\textit{CI)}&\textit{P}\\\\" ///
    "\hline") ///
  footline("\hline" "\end{tabular}")
more

exit
******** End of example5.do ****************************************************
